summaryrefslogtreecommitdiffstats
path: root/src/mbedTLS++/CtrDrbgContext.cpp
diff options
context:
space:
mode:
authorpeterbell10 <peterbell10@live.co.uk>2017-08-30 16:00:06 +0200
committerTiger Wang <ziwei.tiger@outlook.com>2017-08-30 16:00:06 +0200
commit84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7 (patch)
treeaa1648c2ba260b8576673677435481d371eec7b0 /src/mbedTLS++/CtrDrbgContext.cpp
parentUpdate core plugins to latest version (#3951) (diff)
downloadcuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar.gz
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar.bz2
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar.lz
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar.xz
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar.zst
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.zip
Diffstat (limited to '')
-rw-r--r--src/mbedTLS++/CtrDrbgContext.cpp (renamed from src/PolarSSL++/CtrDrbgContext.cpp)10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/PolarSSL++/CtrDrbgContext.cpp b/src/mbedTLS++/CtrDrbgContext.cpp
index c2243db38..bd4a55000 100644
--- a/src/PolarSSL++/CtrDrbgContext.cpp
+++ b/src/mbedTLS++/CtrDrbgContext.cpp
@@ -1,7 +1,7 @@
-
+
// CtrDrbgContext.cpp
// Implements the cCtrDrbgContext class representing a wrapper over CTR-DRBG implementation in PolarSSL
#include "Globals.h"
#include "CtrDrbgContext.h"
@@ -12,9 +12,10 @@
cCtrDrbgContext::cCtrDrbgContext(void) :
- m_EntropyContext(new cEntropyContext),
+ m_EntropyContext(std::make_shared<cEntropyContext>()),
m_IsValid(false)
{
+ mbedtls_ctr_drbg_init(&m_CtrDrbg);
}
@@ -25,6 +26,7 @@ cCtrDrbgContext::cCtrDrbgContext(const std::shared_ptr<cEntropyContext> & a_Entr
m_EntropyContext(a_EntropyContext),
m_IsValid(false)
{
+ mbedtls_ctr_drbg_init(&m_CtrDrbg);
}
@@ -39,7 +41,7 @@ int cCtrDrbgContext::Initialize(const void * a_Custom, size_t a_CustomSize)
return 0;
}
- int res = ctr_drbg_init(&m_CtrDrbg, entropy_func, &(m_EntropyContext->m_Entropy), reinterpret_cast<const unsigned char *>(a_Custom), a_CustomSize);
+ int res = mbedtls_ctr_drbg_seed(&m_CtrDrbg, mbedtls_entropy_func, &(m_EntropyContext->m_Entropy), reinterpret_cast<const unsigned char *>(a_Custom), a_CustomSize);
m_IsValid = (res == 0);
return res;
}
@@ -1,7 +1,7 @@
// CtrDrbgContext.cpp
-// Implements the cCtrDrbgContext class representing a wrapper over CTR-DRBG implementation in PolarSSL
+// Implements the cCtrDrbgContext class representing a wrapper over CTR-DRBG implementation in mbedTLS
#include "Globals.h"
#include "CtrDrbgContext.h"